"""
    File:        rock_paper_scissors2.py
    Author:      Chris Kelly
    Date:        March 2016
    Description: Demonstrates the use of nested dictionaries
                 for simulating a game of "rock, paper, scissors" 
"""

import random

""" Set up initial program data """

# Tuple of strings representing choices
choices = ("Rock", "Paper", "Scissors")

# Mapping of player-computer choice combinations 
# to boolean values -- True, if the combination 
# means player is currently tied with (or losing to)
# the computer
booleans_dict = { 
                    1 : { 1 : True,  2 : True,  3 : False },
                    2 : { 1 : False, 2 : True,  3 : True },
                    3 : { 1 : True,  2 : False, 3 : True } 
                }

# Mapping of player-computer choice combinations 
# to strings representing player messages.  Only 
# the combinations where player and computer made 
# different choices are included.  Ties are handled 
# differently.
strings_dict = {
                    1 : { 2 : "Paper covers Rock...you lose!", 
                          3 : "Rock breaks Scissors...you win!" },
                    2 : { 1 : "Paper covers Rock...you win!",  
                          3 : "Scissors cut Paper...you lose!" },
                    3 : { 1 : "Rock breaks Scissors...you lose!", 
                          2 : "Scissors cut Paper...you win!" } 
                }

""" Start program interactive component """

# Get player's name
player_name = input("What is your name? ")

# Get player's choice
player_choice_num = int (input ("1 = Rock\n2 = Paper\n3 = Scissors\nPlease choose 1, 2, or 3: "))
player_choice = choices[player_choice_num - 1] # Subtract 1 to get a valid tuple index
print()

# Generate computer's choice
computer_choice_num = random.randint(1, 3)
computer_choice = choices[computer_choice_num - 1]

# If player is losing or tied, offer a chance to change
# to another choice
if booleans_dict[player_choice_num][computer_choice_num]:
    answer = input(player_name + ", are you SURE you want to choose " + player_choice + "? ")  
    if answer.lower() == "no":
        player_choice_num = int (input ("1 = Rock\n2 = Paper\n3 = Scissors\nPlease choose 1, 2, or 3: "))
        player_choice = choices[player_choice_num - 1]
        print()

        
print (player_name + ", you chose " + player_choice)
print ("The computer chose " + computer_choice)
print ()
 
# Assign the appropriate value to player_message
if player_choice_num == computer_choice_num:
    player_message = player_name + \
                        ", you and the computer both chose " + \
                        player_choice + ", so it's a tie."
else:
    player_message = strings_dict[player_choice_num][computer_choice_num]

# Print the message to player
print (player_message)